@@ -1,7 +1,5 @@
-/*!
- * \brief Holds some basic card control commands
- *
- * \copyright Copyright (c) 2014-2021 Governikus GmbH & Co. KG, Germany
+/**
+ * Copyright (c) 2014-2025 Governikus GmbH & Co. KG, Germany
  */
 
 #pragma once
@@ -11,8 +9,10 @@
 
 #include <QSharedPointer>
 
+
 class test_CardConnection;
 
+
 namespace governikus
 {
 
@@ -20,19 +20,30 @@ class BaseCardCommand
 	: public QObject
 {
 	Q_OBJECT
+	friend class ::test_CardConnection;
 
 	private:
-		friend class ::test_CardConnection;
 		Q_INVOKABLE void execute();
-
-	protected:
 		QSharedPointer<CardConnectionWorker> mCardConnectionWorker;
 		CardReturnCode mReturnCode;
 
+	protected:
 		explicit BaseCardCommand(QSharedPointer<CardConnectionWorker> pCardConnectionWorker);
 
+		[[nodiscard]] QSharedPointer<CardConnectionWorker> getCardConnectionWorker()
+		{
+			return mCardConnectionWorker;
+		}
+
+
+		void setReturnCode(CardReturnCode pReturnCode)
+		{
+			mReturnCode = pReturnCode;
+		}
+
+
 		virtual void internalExecute() = 0;
-		~BaseCardCommand() override;
+		~BaseCardCommand() override = default;
 
 	public:
 		void run();
