@@ -1,10 +1,5 @@
-/*!
- * \brief Template base class for all steps taken by the state machine.
- *        It is parameterized over the model type and contains a getter for the model.
- *        We cannot parameterize the super class AbstractState because Qt does not
- *        support template classes.
- *
- * \copyright Copyright (c) 2014-2021 Governikus GmbH & Co. KG, Germany
+/**
+ * Copyright (c) 2014-2025 Governikus GmbH & Co. KG, Germany
  */
 
 #pragma once
@@ -29,9 +24,7 @@ class GenericContextContainer
 		}
 
 
-		virtual ~GenericContextContainer() = default;
-
-		virtual QSharedPointer<ContextClass> getContext()
+		[[nodiscard]] QSharedPointer<ContextClass> getContext() const
 		{
 			return mTypedContext;
 		}
