@@ -1,7 +1,5 @@
-/*!
- * \brief Parse tcTokenURL from GET query.
- *
- * \copyright Copyright (c) 2014-2021 Governikus GmbH & Co. KG, Germany
+/**
+ * Copyright (c) 2014-2025 Governikus GmbH & Co. KG, Germany
  */
 
 #include "StateParseTcTokenUrl.h"
@@ -19,7 +17,7 @@ StateParseTcTokenUrl::StateParseTcTokenUrl(const QSharedPointer<WorkflowContext>
 
 void StateParseTcTokenUrl::run()
 {
-	QUrlQuery query(getContext()->getActivationContext()->getActivationURL());
+	QUrlQuery query(getContext()->getActivationUrl());
 	QUrl tcTokenURL(query.queryItemValue(QStringLiteral("tcTokenURL"), QUrl::FullyDecoded));
 	if (tcTokenURL.isValid())
 	{
@@ -31,13 +29,14 @@ void StateParseTcTokenUrl::run()
 		if (query.hasQueryItem(QStringLiteral("tcTokenURL")))
 		{
 			qCritical() << "TcTokenUrl is not valid:" << tcTokenURL.toString();
+			updateStatus(GlobalStatus::Code::Workflow_Wrong_Parameter_Invocation);
+			Q_EMIT fireAbort(FailureCode::Reason::Parse_TcToken_Invalid_Url);
 		}
 		else
 		{
 			qCritical() << "No parameter tcTokenURL";
+			updateStatus(GlobalStatus::Code::Workflow_Wrong_Parameter_Invocation);
+			Q_EMIT fireAbort(FailureCode::Reason::Parse_TcToken_Missing_Url);
 		}
-
-		updateStatus(GlobalStatus::Code::Workflow_Wrong_Parameter_Invocation);
-		Q_EMIT fireAbort();
 	}
 }
